@@ -5,13 +5,13 @@ import json
 
 import jpype
 
-DEFAULT_JAR = str(Path(__file__).parent / "CodeAnalysis.jar")
+DEFAULT_JAR = str(Path(__file__).parent / "JavaAnalysis.jar")
 
 class DependencyAnalyzer:
     def __init__(self, jar_path=DEFAULT_JAR):
         jpype.startJVM(jpype.getDefaultJVMPath(), "-ea", f"-Djava.class.path={jar_path}")
-        self.CFGBuilder = jpype.JClass('codeintelligence.codeanalysis.extractors.dependence.cfg.CFGBuilder')
-        self.PDGBuilder = jpype.JClass('codeintelligence.codeanalysis.extractors.dependence.pdg.PDGBuilder')
+        self.CFGBuilder = jpype.JClass('codetoolkit.janalysis.dg.cfg.CFGBuilder')
+        self.PDGBuilder = jpype.JClass('codetoolkit.janalysis.dg.pdg.PDGBuilder')
 
     def __del__(self):
         if jpype.isJVMStarted():
