@@ -1,5 +1,5 @@
 import logging
-# logging.basicConfig(level = logging.DEBUG)
+logging.basicConfig(level = logging.DEBUG)
 
 from codetoolkit.delimiter import Delimiter
 
